/* TCHK 0.70 - Howard Kapustein's Turbo C library      2-17-88 */
/* Copyright (C) 1988, Howard Kapustein.  All rights reserved. */

/* datehk.h  -  header file for DATEHK.C - date routines */

#include <howard.h>

#ifndef BASE_LEAP_YEAR
typedef enum { Sun, Mon, Tues, Wed, Thrus, Fri, Sat } days;
typedef enum { Jan, Feb, Mar, Apr, May, Jun, Jul, Aug, Sep, Oct, Nov, Dec } months;
typedef struct ddate {
            int dyear;             /* Year - 1900 */
            int dday;              /* Day of month (1-31) */
            months dmon;           /* Month (Jan = 0) */
        };
#define DATENULL        "  -  -  "
#define DATECHAR        '-'
#define DATECHARSTR     "-"
#define DATECHARTEST    "/- "
#define BASE_LEAP_YEAR  1980
#define BASE_JUL_YEAR   1720982.0
#endif


/* function prototypes */
boolean valid_date(int month, int day, int yearnum);  /* check if a date is valid */
boolean isleapyear(int checkyear);          /* is checkyear a leap year */
struct ddate *strtoddate(char *source);     /* convert a string to struct */
char *ddatetostr(struct ddate *source);     /* convert struct to a string */
char *ddatetofull(struct ddate *source);    /* convert struct to a full english string */
char *ddatetoshort(struct ddate *source);   /* convert struct to a short english string */
char *monthexpand(int month);               /* convert # to month name */
int dayofyear(struct ddate *d);    /* calc day # of year (1-365) */
int daysleft(struct ddate *d);     /* calc # days left in year (0-365) */
long int diffddate(struct ddate *start, struct ddate *fini);  /* calc fini - start, in days */
boolean isdate(void *check, int id);        /* is d a valid date of type id */
struct ddate *fulltoddate(char *source);    /* convert full english string to struct */
struct ddate *shorttoddate(char *source);   /* convert short english string to struct */
double GregtoCal(char *greg);               /* convert Gregorian (US) to Calendar */
double GregEurotoCal(char *greg);           /* convert Gregorian (Europe) to Calendar */
double GregJaptoCal(char *greg);            /* convert Gregorian (Japan) to Calendar */
double GregtoCalCent(char *greg);           /* convert Gregorian (US) to Calendar (w/century) */
double GregEurotoCalCent(char *greg);       /* convert Gregorian (Europe) to Calendar (w/century) */
double GregJaptoCalCent(char *greg);        /* convert Gregorian (Japan) to Calendar (w/century) */
char *CaltoGreg(double cal);                /* convert Calendar to Gregorian (US) */
char *CaltoGregEuro(double cal);            /* convert Calendar to Gregorian (Europe) */
char *CaltoGregJap(double cal);             /* convert Calendar to Gregorian (Japan) */
double CaltoJul(double cal);                /* convert Calendar to Julian (Type E) */
double CaltoJulA(double cal);               /* convert Calendar to Julian (Type A) */
double CaltoJulB(double cal);               /* convert Calendar to Julian (Type B) */
double CaltoCalCent(double cal);            /* convert Calendar to Calendar (w/century) */
double CalCenttoCal(double cal);            /* convert Calendar (w/century) to Calendar */
double JultoCal(double jul);                /* convert Julian (Type E) to Calendar */
double JultoCalCent(double jul);            /* convert Julian (Type E) to Calendar (w/century) */
double JulAtoCal(double jul);               /* convert Julian (Type A) to Calendar */
double JulAtoCalCent(double jul);           /* convert Julian (Type A) to Calendar (w/century) */
double JulBtoCal(double jul);               /* convert Julian (Type B) to Calendar */
double JulBtoCalCent(double jul);           /* convert Julian (Type B) to Calendar (w/century) */
int dayofweek(double jul);                  /* day of week (0-6) from a Julian (Type E) date */
char *JultoGreg(double jul);                /* Julian (Type E) to Gregorian (US) */
char *JulAtoGreg(double jul);               /* Julian (Type A) to Gregorian (US) */
char *JulBtoGreg(double jul);               /* Julian (Type B) to Gregorian (US) */
char *JultoGregEuro(double jul);            /* Julian (Type E) to Gregorian (Europe) */
char *JulAtoGregEuro(double jul);           /* Julian (Type A) to Gregorian (Europe) */
char *JulBtoGregEuro(double jul);           /* Julian (Type B) to Gregorian (Europe) */
char *JultoGregJap(double jul);             /* Julian (Type E) to Gregorian (Japan) */
char *JulAtoGregJap(double jul);            /* Julian (Type A) to Gregorian (Japan) */
char *JulBtoGregJap(double jul);            /* Julian (Type B) to Gregorian (Japan) */
struct ddate *Jultoddate(double jul);       /* Julian (Type E) to struct */
struct ddate *JulAtoddate(double jul);      /* Julian (Type A) to struct */
struct ddate *JulBtoddate(double jul);      /* Julian (Type B) to struct */
